@@ -1,4 +1,4 @@
-# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4 -*-
+# -*- Mode:Python; indent-tabs-mode:nil; tab-width:4; encoding:utf8 -*-
 #
 # Copyright 2012 Canonical Ltd
 #
@@ -106,6 +106,8 @@ class FunctionalTestCase(DuplicityTestCase):
         basepython = os.environ.get(u'TOXPYTHON', None)
         if basepython is not None:
             cmd_list.extend([basepython])
+        run_coverage = os.environ.get(u'RUN_COVERAGE', None)
+        if run_coverage is not None:
             cmd_list.extend([u"-m", u"coverage", u"run", u"--source=duplicity", u"-p"])
         cmd_list.extend([u"../bin/duplicity"])
         cmd_list.extend(options)
@@ -170,7 +172,7 @@ class FunctionalTestCase(DuplicityTestCase):
             print(u"...return_val:", return_val, file=sys.stderr)
             raise CmdError(return_val)
 
-    def backup(self, type, input_dir, options=[], **kwargs):
+    def backup(self, type, input_dir, options=[], **kwargs):  # pylint: disable=redefined-builtin
         u"""Run duplicity backup to default directory"""
         options = [type, input_dir, self.backend_url, u"--volsize", u"1"] + options
         before_files = self.get_backend_files()
@@ -182,7 +184,7 @@ class FunctionalTestCase(DuplicityTestCase):
         if self.last_backup == int(now):
             time.sleep(1)
 
-        result = self.run_duplicity(options=options, **kwargs)
+        self.run_duplicity(options=options, **kwargs)
         self.last_backup = int(time.time())
 
         after_files = self.get_backend_files()
